declare class Program {
    name: string;
    versionNumber?: `${number}.${number}.${number}` | undefined;
    config: IProgramConfig;
    private commands;
    private plugins;
    private events;
    tools: Tools;
    args: (string | number)[];
    options: IOptions;
    constructor(name: string, versionNumber?: `${number}.${number}.${number}` | undefined, config?: IProgramConfig);
    version(value: VersionNumber, flags?: string): this;
    help(flags?: string): this;
    get emit(): <K extends ProgramEvents>(type: K, data?: Record<ProgramEvents, Program>[K] | undefined) => void;
    get on(): <K extends ProgramEvents>(type: K, listener: Listener) => void;
    get off(): <K extends ProgramEvents>(type: K, listener?: Listener | undefined) => void;
    get command(): <A extends RawArgs = RawArgs, O extends IOptions = IOptions>(raw: string, description: string, config?: ICommandConfig | undefined) => Command<A, O>;
    get register(): (command: Command<any, any>) => Program;
    get parse(): (input: string[], scope?: ParsingScopes | undefined) => {
        args: (string | number)[];
        options: {
            [key: string]: any;
        };
    };
    run(argv: (string | string)[]): Promise<string | void>;
    private handleError;
}

/**
 * Creates a new instance of option object
 */
declare class Option {
    raw: string;
    description: string;
    name: string;
    aliases: string[];
    isBoolean: boolean;
    isRequired: boolean;
    isVariadic: boolean;
    isNegated: boolean;
    default?: any;
    constructor(raw: string, description: string, opts: {
        default?: any;
    });
}

/**
 * Creates a new instances of the command object
 */
declare class Command<T extends RawArgs, O extends IOptions> {
    name: string;
    description: string;
    private manager?;
    private _action?;
    private examples;
    raw: string;
    _version: VersionNumber;
    _usage: string;
    keys: Record<'help' | 'version', string>;
    aliases: string[];
    args: IParsedArg[];
    options: Option[];
    config?: ICommandConfig;
    constructor(name: string, description: string, config?: ICommandConfig);
    get isDefault(): boolean;
    get isGlobal(): boolean;
    get isImplemented(): boolean;
    version(value?: VersionNumber, flags?: string): this;
    makeDefault(): this;
    example(example: CommandExample): this;
    usage(text: string): this;
    alias(name: string): this;
    option(raw: TypedRawOption<keyof O>, description: string, defaultValue?: O[keyof O]): this;
    link(manager: CommandManager): void;
    execute(args: T, options: O, tools: Tools): void | Promise<void>;
    hasOption(name: string): Option | undefined;
    validate(args: RawArgs, parsedOptions: IOptions): void;
    action(func: Action<T, O>): Program;
    getVersion(print?: boolean): string | undefined;
    help(flags?: string): this;
    printHelp(): void;
}

/**
 * Creates a new instance of the command manager
 */
declare class CommandManager {
    program: Program;
    private commands;
    global: Command<RawArgs, IOptions>;
    tools: Tools;
    constructor(program: Program);
    get count(): number;
    get all(): Command<RawArgs, IOptions>[];
    parse: (input: string[], scope?: ParsingScopes) => {
        args: (string | number)[];
        options: {
            [key: string]: any;
        };
    };
    private getParserOptions;
    register: (command: Command<any, any>) => Program;
    add: <A extends RawArgs = RawArgs, O extends IOptions = IOptions>(raw: string, description: string, config?: ICommandConfig) => Command<A, O>;
    find: (query: string) => Command<RawArgs, IOptions> | undefined;
}

interface Tools {
}
interface ParserOptions {
    /** When `true`, populate the result `_` with everything before the `--` and
     * the result `['--']` with everything after the `--`. Here's an example:
     * Defaults to `false`.
     */
    '--'?: boolean;
    /** An object mapping string names to strings or arrays of string argument
     * names to use as aliases. */
    alias?: Record<string, string | string[]>;
    /** A boolean, string or array of strings to always treat as booleans. If
     * `true` will treat all double hyphenated arguments without equal signs as
     * `boolean` (e.g. affects `--foo`, not `-f` or `--foo=bar`) */
    boolean?: boolean | string | string[];
    /** An object mapping string argument names to default values. */
    default?: Record<string, unknown>;
    /** When `true`, populate the result `_` with everything after the first
     * non-option. */
    stopEarly?: boolean;
    /** A string or array of strings argument names to always treat as strings. */
    string?: string | string[];
    /** A string or array of strings argument names to always treat as arrays.
     * Collectable options can be used multiple times. All values will be
     * colelcted into one array. If a non-collectable option is used multiple
     * times, the last value is used. */
    collect?: string | string[];
    /** A string or array of strings argument names which can be negated
     * by prefixing them with `--no-`, like `--no-config`. */
    negatable?: string | string[];
    /** A function which is invoked with a command line parameter not defined in
     * the `options` configuration object. If the function returns `false`, the
     * unknown option is not added to `parsedArgs`. */
    unknown?: (arg: string, key?: string, value?: unknown) => unknown;
}
interface IProgramConfig {
    /**
     * Configuration options to pass onto the underlying parser
     */
    parser?: ParserOptions;
    /**
     * Array of plugins to register in the program
     */
    plugins?: IPlugin[];
    /**
     * Custom tools which are accessible anywhere inside the program and command actions.
     */
    tools?: Partial<Tools>;
    /**
     * Formatter hooks to register and provide custom formatting for `version` and `help` outputs
     */
    formatters?: {
        version?: (this: Required<IProgramConfig>, version: VersionNumber, name: string) => string;
        help?: (this: Required<IProgramConfig>, sections: HelpSection[]) => HelpSection[];
    };
    /**
     * Should print help output if no commands are found
     * @default true
     */
    printHelpOnNotFound?: boolean;
    /**
     * Should capture any unhandled errors raised inside the program other than `ZorsError`
     * @default false
     */
    captureErrors?: boolean;
    /**
     * Enable concurrent initialization for bootstrapping plugins, if your plugins depend on each other,
     * we suggest keeping disabling this, as it won't run your plugins sequentially.
     * @default false
     */
    concurrentBootstrap?: boolean;
}
declare type Arg = string | number | undefined;
declare type RawArgs = (Arg | Arg[])[] | undefined;
declare type IOptions = Record<string, string | number | boolean>;
declare type Letter = 'a' | 'b' | 'c' | 'd' | 'e' | 'f' | 'g' | 'h' | 'i' | 'j' | 'k' | 'l' | 'm' | 'n' | 'o' | 'p' | 'q' | 'r' | 's' | 't' | 'u' | 'v' | 'w' | 'x' | 'y' | 'z';
declare type FirstLetterOf<S extends string> = string extends S ? string : {
    [L in Letter]: S extends `${L}${string}` ? L : never;
}[Letter];
declare type LooseAutoComplete<T extends string> = T | Omit<string, T>;
declare type ParsingScopes = LooseAutoComplete<'*' | 'global'>;
declare type TypedRawOption<T extends string | number | symbol> = T extends string ? LooseAutoComplete<`--${T}` | `-${FirstLetterOf<T>}` | `-${FirstLetterOf<T>}, --${T}`> : string;
interface Commands {
}
declare type ProgramEvents = 'register' | 'error' | 'done' | `run:${keyof Commands}` | `run:*`;
interface IParsedArg {
    required: boolean;
    value: string;
    variadic: boolean;
}
interface ICommandConfig {
    allowUnknownOptions?: boolean;
    ignoreOptionDefaultValue?: boolean;
}
declare type VersionNumber = `${number}.${number}.${number}`;
declare type Action<A extends RawArgs, O extends IOptions = IOptions> = (this: Command<A, O>, args: A, opts: O, tools: Tools) => Promise<void> | void;
interface DefineCommandOptions<A extends RawArgs, O extends IOptions> {
    action: Action<A, O>;
    description: string;
    usage?: string;
    aliases?: string[];
    version?: {
        value?: VersionNumber;
        flags?: string;
    };
    examples?: CommandExample[];
    options?: {
        raw: TypedRawOption<keyof O>;
        description: string;
        default?: any;
    }[];
    config?: ICommandConfig;
}
declare type Listener = () => void;
interface IPlugin {
    name: string;
    build: (program: Program) => Program | Promise<Program>;
}
interface HelpSection {
    title?: string;
    body: string;
}
declare type CommandExample = ((bin: string) => string) | string;

/**
 * A fascade function to create a new instance of Command
 */
declare function defineCommand<A extends RawArgs = RawArgs, O extends IOptions = IOptions>(raw: string, options: DefineCommandOptions<A, O>): Command<A, O>;
/**
 * Creates a new Program
 * @param name Name of the CLI program
 * @param version Version number (SEMVER)
 * @param config
 * @returns
 */
declare function zors(name: string, version?: VersionNumber, config?: Omit<IProgramConfig, 'tools'> & {
    tools?: Record<string, any>;
}): Program;

export { Command, Commands, IPlugin, IProgramConfig, Program, Tools, VersionNumber, defineCommand, zors };
