// src/lib/error.ts
var ZorsError = class extends Error {
  constructor(message) {
    super(message);
    this.name = this.constructor.name;
    if (typeof Error.captureStackTrace === "function") {
      Error.captureStackTrace(this, this.constructor);
    } else {
      this.stack = new Error(message)?.stack;
    }
  }
};

// src/lib/utils.ts
var removeBrackets = (raw) => raw.replace(/[<[].+/, "").trim();
var findAllBrackets = (raw) => {
  const ANGLED_BRACKET_RE_GLOBAL = /<([^>]+)>/g;
  const SQUARE_BRACKET_RE_GLOBAL = /\[([^\]]+)\]/g;
  const res = [];
  const parse2 = (match) => {
    let variadic = false;
    let value = match[1];
    if (value.endsWith("...")) {
      value = value.slice(-3);
      variadic = true;
    }
    return {
      required: match[0].startsWith("<"),
      value,
      variadic
    };
  };
  let angledMatch;
  while (angledMatch = ANGLED_BRACKET_RE_GLOBAL.exec(raw)) {
    res.push(parse2(angledMatch));
  }
  let squareMatch;
  while (squareMatch = SQUARE_BRACKET_RE_GLOBAL.exec(raw)) {
    res.push(parse2(squareMatch));
  }
  return res;
};
var findLongest = (arr) => {
  return arr.sort((a, b) => {
    return a.length > b.length ? -1 : 1;
  })[0];
};
var padRight = (str, length) => {
  return str.length >= length ? str : `${str}${" ".repeat(length - str.length)}`;
};
var camelcase = (input) => {
  return input.replace(/([a-z])-([a-z])/g, (_, p1, p2) => {
    return p1 + p2.toUpperCase();
  });
};
var camelcaseOptionName = (name) => {
  return name.split(".").map((v, i) => i === 0 ? camelcase(v) : v).join(".");
};
function hasOwn(obj, key) {
  return Object.prototype.hasOwnProperty.call(obj, key);
}
function assert(exp) {
  if (!exp)
    throw new ZorsError(`Assertion error`);
}
function get(obj, key) {
  if (hasOwn(obj, key)) {
    return obj[key];
  }
}
function getForce(obj, key) {
  const v = get(obj, key);
  assert(v != null);
  return v;
}
function isNumber(x) {
  if (typeof x === "number")
    return true;
  if (/^0x[0-9a-f]+$/i.test(String(x)))
    return true;
  return /^[-+]?(?:\d+(?:\.\d*)?|\.\d+)(e[-+]?\d+)?$/.test(String(x));
}
function merge(obj, ...sources) {
  for (let source of sources) {
    for (let key in source) {
      if (!source[key] && typeof source[key] !== "boolean")
        continue;
      obj[key] = replace(obj[key], source[key]);
    }
  }
  return obj;
}
var isArray = (value) => Array.isArray(value);
var isObject = (value) => value && value.constructor === Object;
var replace = (value, next) => {
  if (isArray(value) && isArray(next)) {
    return next.map((val, i) => replace(val[i], val));
  }
  if (isObject(value) && isObject(next)) {
    return merge(value, next);
  }
  return next;
};

// src/lib/parser.ts
function hasKey(obj, keys) {
  let o = obj;
  keys.slice(0, -1).forEach((key2) => {
    o = get(o, key2) ?? {};
  });
  const key = keys[keys.length - 1];
  return key in o;
}
function parse(args, {
  "--": doubleDash = false,
  alias = {},
  boolean = false,
  default: defaults = {},
  stopEarly = false,
  string = [],
  collect = [],
  negatable = [],
  unknown = (i) => i
} = {}) {
  const flags = {
    bools: {},
    strings: {},
    unknownFn: unknown,
    allBools: false,
    collect: {},
    negatable: {}
  };
  if (boolean !== void 0) {
    if (typeof boolean === "boolean") {
      flags.allBools = !!boolean;
    } else {
      const booleanArgs = typeof boolean === "string" ? [boolean] : boolean;
      for (const key of booleanArgs.filter(Boolean)) {
        flags.bools[key] = true;
      }
    }
  }
  const aliases = {};
  if (alias !== void 0) {
    for (const key in alias) {
      const val = getForce(alias, key);
      if (typeof val === "string") {
        aliases[key] = [val];
      } else {
        aliases[key] = val;
      }
      for (const alias2 of getForce(aliases, key)) {
        aliases[alias2] = [key].concat(aliases[key].filter((y) => alias2 !== y));
      }
    }
  }
  if (string !== void 0) {
    const stringArgs = typeof string === "string" ? [string] : string;
    for (const key of stringArgs.filter(Boolean)) {
      flags.strings[key] = true;
      const alias2 = get(aliases, key);
      if (alias2) {
        for (const al of alias2) {
          flags.strings[al] = true;
        }
      }
    }
  }
  if (collect !== void 0) {
    const collectArgs = typeof collect === "string" ? [collect] : collect;
    for (const key of collectArgs.filter(Boolean)) {
      flags.collect[key] = true;
      const alias2 = get(aliases, key);
      if (alias2) {
        for (const al of alias2) {
          flags.collect[al] = true;
        }
      }
    }
  }
  if (negatable !== void 0) {
    const negatableArgs = typeof negatable === "string" ? [negatable] : negatable;
    for (const key of negatableArgs.filter(Boolean)) {
      flags.negatable[key] = true;
      const alias2 = get(aliases, key);
      if (alias2) {
        for (const al of alias2) {
          flags.negatable[al] = true;
        }
      }
    }
  }
  const argv = { _: [] };
  function argDefined(key, arg) {
    return flags.allBools && /^--[^=]+$/.test(arg) || get(flags.bools, key) || !!get(flags.strings, key) || !!get(aliases, key);
  }
  function setKey(obj, name, value, collect2 = true) {
    let o = obj;
    const keys = name.split(".");
    keys.slice(0, -1).forEach(function(key2) {
      if (get(o, key2) === void 0) {
        o[key2] = {};
      }
      o = get(o, key2);
    });
    const key = keys[keys.length - 1];
    const collectable = collect2 && !!get(flags.collect, name);
    if (!collectable) {
      o[key] = value;
    } else if (get(o, key) === void 0) {
      o[key] = [value];
    } else if (Array.isArray(get(o, key))) {
      o[key].push(value);
    } else {
      o[key] = [get(o, key), value];
    }
  }
  function setArg(key, val, arg = void 0, collect2) {
    if (arg && flags.unknownFn && !argDefined(key, arg)) {
      if (flags.unknownFn(arg, key, val) === false)
        return;
    }
    const value = !get(flags.strings, key) && isNumber(val) ? Number(val) : val;
    setKey(argv, key, value, collect2);
    const alias2 = get(aliases, key);
    if (alias2) {
      for (const x of alias2) {
        setKey(argv, x, value, collect2);
      }
    }
  }
  function aliasIsBoolean(key) {
    return getForce(aliases, key).some((x) => typeof get(flags.bools, x) === "boolean");
  }
  let notFlags = [];
  if (args.includes("--")) {
    notFlags = args.slice(args.indexOf("--") + 1);
    args = args.slice(0, args.indexOf("--"));
  }
  for (let i = 0; i < args.length; i++) {
    const arg = args[i];
    if (/^--.+=/.test(arg)) {
      const m = arg.match(/^--([^=]+)=(.*)$/s);
      assert(m != null);
      const [, key, value] = m;
      if (flags.bools[key]) {
        const booleanValue = value !== "false";
        setArg(key, booleanValue, arg);
      } else {
        setArg(camelcaseOptionName(key), value, arg);
      }
    } else if (/^--no-.+/.test(arg) && get(flags.negatable, arg.replace(/^--no-/, ""))) {
      const m = arg.match(/^--no-(.+)/);
      assert(m != null);
      setArg(m[1], false, arg, false);
    } else if (/^--.+/.test(arg)) {
      const m = arg.match(/^--(.+)/);
      assert(m != null);
      const [, key] = m;
      const next = args[i + 1];
      if (next !== void 0 && !/^-/.test(next) && !get(flags.bools, key) && !flags.allBools && (get(aliases, key) ? !aliasIsBoolean(key) : true)) {
        setArg(key, next, arg);
        i++;
      } else if (/^(true|false)$/.test(next)) {
        setArg(key, next === "true", arg);
        i++;
      } else {
        setArg(key, get(flags.strings, key) ? "" : true, arg);
      }
    } else if (/^-[^-]+/.test(arg)) {
      const letters = arg.slice(1, -1).split("");
      let broken = false;
      for (let j = 0; j < letters.length; j++) {
        const next = arg.slice(j + 2);
        if (next === "-") {
          setArg(letters[j], next, arg);
          continue;
        }
        if (/[A-Za-z]/.test(letters[j]) && /=/.test(next)) {
          setArg(letters[j], next.split(/=(.+)/)[1], arg);
          broken = true;
          break;
        }
        if (/[A-Za-z]/.test(letters[j]) && /-?\d+(\.\d*)?(e-?\d+)?$/.test(next)) {
          setArg(letters[j], next, arg);
          broken = true;
          break;
        }
        if (letters[j + 1] && letters[j + 1].match(/\W/)) {
          setArg(letters[j], arg.slice(j + 2), arg);
          broken = true;
          break;
        } else {
          setArg(letters[j], get(flags.strings, letters[j]) ? "" : true, arg);
        }
      }
      const [key] = arg.slice(-1);
      if (!broken && key !== "-") {
        if (args[i + 1] && !/^(-|--)[^-]/.test(args[i + 1]) && !get(flags.bools, key) && (get(aliases, key) ? !aliasIsBoolean(key) : true)) {
          setArg(key, args[i + 1], arg);
          i++;
        } else if (args[i + 1] && /^(true|false)$/.test(args[i + 1])) {
          setArg(key, args[i + 1] === "true", arg);
          i++;
        } else {
          setArg(key, get(flags.strings, key) ? "" : true, arg);
        }
      }
    } else {
      if (!flags.unknownFn || flags.unknownFn(arg) !== false) {
        argv._.push(flags.strings["_"] ?? !isNumber(arg) ? arg : Number(arg));
      }
      if (stopEarly) {
        argv._.push(...args.slice(i + 1));
        break;
      }
    }
  }
  for (const [key, value] of Object.entries(defaults)) {
    if (!hasKey(argv, key.split("."))) {
      setKey(argv, key, value);
      if (aliases[key]) {
        for (const x of aliases[key]) {
          setKey(argv, x, value);
        }
      }
    }
  }
  for (const key of Object.keys(flags.bools)) {
    if (!hasKey(argv, key.split("."))) {
      const value = get(flags.collect, key) ? [] : false;
      setKey(argv, key, value, false);
    }
  }
  for (const key of Object.keys(flags.strings)) {
    if (!hasKey(argv, key.split(".")) && get(flags.collect, key)) {
      setKey(argv, key, [], false);
    }
  }
  if (doubleDash) {
    argv["--"] = [];
    for (const key of notFlags) {
      argv["--"].push(key);
    }
  } else {
    for (const key of notFlags) {
      argv._.push(key);
    }
  }
  return argv;
}

// src/modules/command/option.ts
var Option = class {
  constructor(raw, description, opts) {
    this.raw = raw;
    this.description = description;
    this.aliases = [];
    this.isBoolean = false;
    this.isRequired = false;
    this.isVariadic = false;
    this.isNegated = false;
    const { default: defaultValue = null } = opts || {};
    this.default = defaultValue;
    this.raw = raw.replace(/\.\*/g, "");
    this.isVariadic = /\w\.\.\.[>\]]$/.test(raw);
    this.aliases = removeBrackets(raw).split(",").map((v) => {
      let name = v.trim().replace(/^-{1,2}/, "");
      if (name.startsWith("no-")) {
        this.isNegated = true;
        name = name.replace(/^no-/, "");
      }
      return camelcaseOptionName(name);
    }).sort((a, b) => a.length > b.length ? 1 : -1);
    this.name = this.aliases.slice(-1)[0];
    if (this.isNegated && this.default == null) {
      this.default = true;
    }
    if (raw.includes("<")) {
      this.isRequired = true;
    } else if (raw.includes("[")) {
      this.isRequired = false;
    } else {
      this.isBoolean = true;
    }
  }
};

// src/modules/command/command.ts
var defaulOptions = {
  allowUnknownOptions: false,
  ignoreOptionDefaultValue: false
};
var Command = class {
  constructor(name, description, config) {
    this.name = name;
    this.description = description;
    this.examples = [];
    this.raw = "";
    this._version = "0.0.0";
    this._usage = "";
    this.keys = {
      help: "help",
      version: "version"
    };
    this.aliases = [];
    this.args = [];
    this.options = [];
    this.config = merge(defaulOptions, config);
  }
  get isDefault() {
    return this.name === "" || this.aliases.includes("!");
  }
  get isGlobal() {
    return this.name === this.manager?.program.name;
  }
  get isImplemented() {
    return typeof this._action === "function";
  }
  version(value = "0.0.0", flags = "-v, --version") {
    this.options = this.options.filter((o) => !(o.name === this.keys.version));
    this._version = value;
    const item = new Option(flags, "Display version number", {});
    this.keys.version = item.name;
    this.options.push(item);
    return this;
  }
  makeDefault() {
    if (!this.isDefault) {
      this.aliases.push("!");
    }
    return this;
  }
  example(example) {
    this.examples.push(example);
    return this;
  }
  usage(text) {
    this._usage = text.trim();
    return this;
  }
  alias(name) {
    this.aliases.push(name);
    return this;
  }
  option(raw, description, defaultValue) {
    const item = new Option(raw, description, {
      default: defaultValue
    });
    this.options.push(item);
    return this;
  }
  link(manager) {
    this.manager = manager;
  }
  execute(args, options, tools) {
    if (!this.isImplemented) {
      throw new ZorsError(`Command ${this.name} is not implemented.`);
    }
    return this._action(args, options, tools);
  }
  hasOption(name) {
    const _name = name.split(".")[0];
    return this.options.find((opt) => opt.aliases.includes(_name));
  }
  validate(args, parsedOptions) {
    const required = this.args.filter((a) => a.required);
    if (!this.manager)
      return;
    const options = [...this.options];
    if (args.length < required.length) {
      throw new ZorsError(`Missing required arg for command \`${this.raw}\``);
    }
    if (!this.config?.allowUnknownOptions) {
      for (const { name } of options) {
        if (name !== "--" && !this.hasOption(name) && !this.manager.global.hasOption(name)) {
          throw new ZorsError(`Unknown option \`${name.length > 1 ? `--${name}` : `-${name}`}\``);
        }
      }
    }
    for (const option of options) {
      const value = parsedOptions[option.name.split(".")[0]];
      if (option.isRequired) {
        const hasNegated = options.some((o) => o.isNegated && o.aliases.includes(option.name));
        if (value === true || value === false && !hasNegated || value === void 0) {
          throw new ZorsError(`option \`${option.raw}\` value is missing`);
        }
      }
    }
  }
  action(func) {
    this._action = func;
    return this.manager?.program;
  }
  getVersion(print = true) {
    if (!this.manager)
      return;
    const name = (this.isGlobal || this.isDefault ? this.manager.program.name : this.name).toUpperCase();
    const config = this.manager.program.config;
    const customFormatter = config?.formatters?.version;
    let msg;
    if (customFormatter) {
      msg = customFormatter.apply(config, [
        this._version,
        name
      ]);
    } else {
      msg = `${name}/${`v${this._version}`}`;
    }
    if (print) {
      console.log(msg);
    }
    return msg;
  }
  help(flags = "-h, --help") {
    this.option(flags, "Display help output");
    return this;
  }
  printHelp() {
    const commands = this.manager.all;
    const config = this.manager?.program.config;
    const formatters = config?.formatters;
    const global = this.manager.global;
    const version = this.getVersion(false) || `${this.name}/v${this._version}`;
    let sections = [{ body: version }];
    sections.push({
      title: "Usage",
      body: `  $ ${global.name} ${this._usage || this.raw}`
    });
    const hasCommands = commands.length > 0;
    const show = (global.isGlobal || global.isDefault) && hasCommands;
    if (show) {
      const longest = findLongest(commands.map((c) => c.raw));
      sections.push({
        title: "Commands",
        body: commands.map((c) => `  ${padRight(c.raw, longest.length)}  ${c.description}`).join("\n")
      });
      sections.push({
        title: `For more info, run any command with the \`--help\` flag`,
        body: commands.map((c) => `  $ ${global.name}${c.name === "" ? "" : ` ${c.name}`} --help`).join("\n")
      });
    }
    let options = this.isGlobal ? global.options : [...this.options, ...global.options || []];
    if (!this.isGlobal && !this.isDefault) {
      options = options.filter((option) => option.name !== "version");
    }
    if (options.length > 0) {
      const longest = findLongest(options.map((option) => option.raw));
      sections.push({
        title: "Options",
        body: options.map((o) => {
          return `  ${padRight(o.raw, longest.length)}  ${o.description} ${!o.default ? "" : `(default: ${o.default})`}`;
        }).join("\n")
      });
    }
    if (this.examples.length > 0) {
      sections.push({
        title: "Examples",
        body: this.examples.map((example) => {
          if (typeof example === "function") {
            return example(this.name);
          }
          return `  $ ${global.name ? `${global.name} ` : ""}${example}`;
        }).join("\n")
      });
    }
    if (formatters?.help) {
      sections = formatters.help.apply(config, [sections]) || sections;
    }
    console.log(sections.map((section) => section.title ? `${section.title}:
${section.body}` : section.body).join("\n\n"));
  }
};

// src/modules/command/index.ts
var CommandManager = class {
  constructor(program) {
    this.program = program;
    this.commands = /* @__PURE__ */ new Map();
    this.parse = (input, scope) => {
      let commands = [this.global];
      if (scope === "*") {
        commands = Array.from(this.commands.values());
      }
      const found = this.find(String(scope));
      if (scope !== "global" && found) {
        commands = [found];
      }
      const { _: args, ...options } = parse(input, this.getParserOptions(commands));
      return { args, options };
    };
    this.register = (command) => {
      if (this.commands.has(command.name)) {
        throw new ZorsError(`A Command is already registered by the name \`${command.name}\``);
      }
      command.link(this);
      this.commands.set(command.name, command);
      this.program.emit("register");
      return this.program;
    };
    this.add = (raw, description, config) => {
      const command = new Command(removeBrackets(raw), description, config);
      command.args = findAllBrackets(raw);
      command.version(command._version);
      command.help();
      command.raw = raw;
      this.register(command);
      return command;
    };
    this.find = (query) => {
      for (let [name, command] of this.commands.entries()) {
        if (name === query) {
          return command;
        }
        if (command.aliases.includes(query)) {
          return command;
        }
        if (command.isDefault) {
          return command;
        }
      }
    };
    this.global = new Command(program.name, "");
    this.global.link(this);
    this.tools = program.tools;
  }
  get count() {
    return this.commands.size;
  }
  get all() {
    return Array.from(this.commands.values());
  }
  getParserOptions(commands) {
    const config = {
      alias: {},
      default: {},
      boolean: [],
      negatable: []
    };
    const allOptions = commands.reduce((acc, curr) => acc.concat(curr.options), []);
    for (const [index, option] of allOptions.entries()) {
      const last = option.aliases.slice(-1)[0];
      if (option.aliases.length > 0) {
        config.alias[last] = option.aliases.slice();
      }
      if (option.default) {
        config.default[last] = option.default;
      }
      if (option.isBoolean) {
        if (option.isNegated && Array.isArray(config.negatable)) {
          config.negatable.push(option.name);
          const hasStringTypeOption = allOptions.some((o, i) => {
            return i !== index && o.aliases.some((name) => option.aliases.includes(name)) && typeof o.isRequired === "boolean";
          });
          if (!hasStringTypeOption && Array.isArray(config.boolean)) {
            config.boolean.push(last);
          }
        } else if (Array.isArray(config.boolean)) {
          config.boolean.push(last);
        }
      }
    }
    for (let command of commands) {
      config.alias[command.name] = command.aliases;
    }
    return merge({}, this.program.config?.parser, config);
  }
};

// src/modules/events.ts
var EventsManager = class {
  constructor() {
    this.events = /* @__PURE__ */ new Map();
    this.on = (type, listener) => {
      const listeners = this.events.get(type);
      if (listeners) {
        listeners.push(listener);
      } else {
        this.events.set(type, [listener]);
      }
    };
    this.off = (type, listener) => {
      const listeners = this.events.get(type);
      if (listeners) {
        if (listener) {
          listeners.splice(listeners.indexOf(listener) >>> 0, 1);
        } else {
          this.events.set(type, []);
        }
      }
    };
    this.emit = (type, data) => {
      const listeners = this.events.get(type);
      if (listeners) {
        listeners.forEach((listener) => {
          listener();
        });
      }
    };
  }
};

// src/modules/plugins.ts
var PluginsManager = class {
  constructor(program) {
    this.plugins = /* @__PURE__ */ new Map();
    this.program = program;
  }
  register(input) {
    if (isArray(input)) {
      for (let plugin of input) {
        this.plugins.set(plugin.name, plugin);
      }
    } else {
      this.plugins.set(input.name, input);
    }
    return this;
  }
  async visit(callback) {
    if (this.program.config.concurrentBootstrap) {
      const plugins = Array.from(this.plugins.values());
      const promises = plugins.map((p) => callback(p));
      return Promise.all(promises);
    }
    for (let [_, plugin] of this.plugins.entries()) {
      const maybeAsync = callback(plugin);
      if (maybeAsync instanceof Promise) {
        await maybeAsync;
      }
    }
  }
  attach() {
    return this.visit((plugin) => {
      let next = plugin.build(this.program);
      if (!next) {
        throw new ZorsError(`Plugins need to return \`program\`, ${plugin.name}: returns ${next}`);
      }
      if (next instanceof Promise) {
        return next.then((p) => {
          this.program = p;
        });
      }
      this.program = next;
    });
  }
  find(name) {
    return this.plugins.get(name);
  }
};

// src/modules/program.ts
var defaultOptions = {
  printHelpOnNotFound: true,
  captureErrors: false,
  concurrentBootstrap: false,
  formatters: {},
  parser: {},
  plugins: [],
  tools: {}
};
var Program = class {
  constructor(name, versionNumber, config = {}) {
    this.name = name;
    this.versionNumber = versionNumber;
    this.config = config;
    this.tools = {};
    this.args = [];
    this.options = {};
    this.config = merge(defaultOptions, config);
    this.commands = new CommandManager(this);
    this.plugins = new PluginsManager(this);
    this.events = new EventsManager();
    this.tools = merge(this.tools, config?.tools);
    this.plugins.register(config?.plugins || []);
    if (versionNumber?.trim()) {
      this.version(versionNumber);
    }
  }
  version(value, flags) {
    this.commands.global.version(value, flags);
    return this;
  }
  help(flags = "-h, --help") {
    this.commands.global.option(flags, "Display help output");
    return this;
  }
  get emit() {
    return this.events.emit;
  }
  get on() {
    return this.events.on;
  }
  get off() {
    return this.events.off;
  }
  get command() {
    return this.commands.add;
  }
  get register() {
    return this.commands.register;
  }
  get parse() {
    return this.commands.parse;
  }
  async run(argv) {
    await this.plugins.attach();
    const {
      args: [bin]
    } = this.parse(argv);
    const {
      args: [first, ...args],
      options
    } = this.parse(argv, bin);
    this.args = args;
    this.options = options;
    const name = String(first);
    let found = this.commands.find(name);
    const global = this.commands.global;
    if (global.isImplemented) {
      found = global;
    }
    if (found && options[found.keys.version]) {
      return found.getVersion();
    } else if (options[global.keys.version]) {
      return global.getVersion();
    }
    if (found && options[found.keys.help]) {
      return found.printHelp();
    } else if (options[global.keys.help]) {
      return global.printHelp();
    }
    if (!found) {
      this.emit(`run:*`);
      if (this.config?.printHelpOnNotFound) {
        global.printHelp();
      }
      return this.emit("done");
    }
    found.validate(args, options);
    this.emit(`run:${found.name}`);
    try {
      const ran = found.execute(args, options, this.tools);
      if (ran?.then) {
        await ran;
      }
    } catch (error) {
      this.handleError(error);
    }
    this.emit("done");
  }
  handleError(error) {
    if (error instanceof ZorsError) {
      throw error;
    } else if (!this.config.captureErrors) {
      throw error;
    }
    this.emit("error");
  }
};

// src/functions.ts
function defineCommand(raw, options) {
  const command = new Command(removeBrackets(raw), options.description, options.config);
  command.raw = raw;
  command.version(options.version?.value, options.version?.flags);
  command.help();
  command.args = findAllBrackets(raw);
  options.aliases?.forEach((al) => command.alias(al));
  options.options?.forEach((el) => command.option(el.raw, el.description, el.default));
  command.usage(options.usage || "");
  options.examples?.forEach((el) => command.example(el));
  command.action(options.action);
  return command;
}
function zors(name, version, config) {
  return new Program(name, version, config);
}
//! MODIFICATION: Parse keys as camel case

export { Command, Program, defineCommand, zors };
